Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(801)

Unified Diff: mojo/edk/embedder/pending_process_connection.h

Issue 2735113003: Changing SpawnChild to return a struct.
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/edk/embedder/parcelable_channel.h ('k') | mojo/edk/embedder/pending_process_connection.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/edk/embedder/pending_process_connection.h
diff --git a/mojo/edk/embedder/pending_process_connection.h b/mojo/edk/embedder/pending_process_connection.h
index 1f5cad9ff63e490541ada3a52af50d4e9723c491..2bd473f850b0269fccd44efba6ac45006407c079 100644
--- a/mojo/edk/embedder/pending_process_connection.h
+++ b/mojo/edk/embedder/pending_process_connection.h
@@ -10,6 +10,7 @@
#include "base/callback.h"
#include "base/macros.h"
#include "base/process/process_handle.h"
+#include "mojo/edk/embedder/connection_param.h"
#include "mojo/edk/embedder/scoped_platform_handle.h"
#include "mojo/edk/system/system_impl_export.h"
#include "mojo/public/cpp/system/message_pipe.h"
@@ -88,8 +89,8 @@ class MOJO_SYSTEM_IMPL_EXPORT PendingProcessConnection {
// Connects to the process. This must be called at most once, with the process
// handle in |process|.
//
// |channel| is the platform handle of an OS pipe which can be used to
// communicate with the connected process. The other end of that pipe must
// ultimately be passed to mojo::edk::SetParentPipeHandle in the remote
// process, and getting that end of the pipe into the other process is the
// embedder's responsibility.
@@ -101,7 +102,7 @@ class MOJO_SYSTEM_IMPL_EXPORT PendingProcessConnection {
// created by CreateMessagePipe above) will be cleaned up at that time.
void Connect(
base::ProcessHandle process,
- ScopedPlatformHandle channel,
+ ConnectionParam connection_param,
const ProcessErrorCallback& error_callback = ProcessErrorCallback());
private:
« no previous file with comments | « mojo/edk/embedder/parcelable_channel.h ('k') | mojo/edk/embedder/pending_process_connection.cc » ('j') | no next file with comments »
@@ -88,8 +89,8 @@ class MOJO_SYSTEM_IMPL_EXPORT PendingProcessConnection {
// handle in |process|.
//
- // |channel| is the platform handle of an OS pipe which can be used to
- // communicate with the connected process. The other end of that pipe must
+ // |connection_param| is the platform handle of an OS pipe which can be used
+ // to communicate with the connected process. The other end of that pipe must
// ultimately be passed to mojo::edk::SetParentPipeHandle in the remote
// process, and getting that end of the pipe into the other process is the

Powered by Google App Engine
This is Rietveld 408576698